@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """ Test Cases
-    Please see README.rst or DOCS.rst or http://bserve.webhop.org/wiki/django_polymorphic
+    Please see README.rst or DOCS.rst or http://chrisglass.github.com/django_polymorphic/
 """
 
-import settings
+from django.conf import settings
 import sys
 from pprint import pprint
 
@@ -582,7 +582,7 @@ __test__ = {"doctest": """
 >>> type(ModelWithMyManager.objects)
 <class 'polymorphic.tests.MyManager'>
 >>> type(ModelWithMyManager._default_manager)
-<class 'polymorphic.tests.MyManager'>
+<class 'polymorphic.manager.PolymorphicManager'>
 
 
 ### Manager Inheritance
@@ -592,11 +592,11 @@ __test__ = {"doctest": """
 
 # check for correct default manager
 >>> type(MROBase1._default_manager)
-<class 'polymorphic.tests.MyManager'>
+<class 'polymorphic.manager.PolymorphicManager'>
 
 # Django vanilla inheritance does not inherit MyManager as _default_manager here
 >>> type(MROBase2._default_manager)
-<class 'polymorphic.tests.MyManager'>
+<class 'polymorphic.manager.PolymorphicManager'>
 
 
 ### fixed issue in PolymorphicModel.__getattribute__: field name same as model name
@@ -618,22 +618,30 @@ __test__ = {"doctest": """
 #>>> print 'DiamondXY fields 1: field_b "%s", field_x "%s", field_y "%s"' % (o.field_b, o.field_x, o.field_y)
 #DiamondXY fields 1: field_b "a", field_x "x", field_y "y"
 
-# test for github issue
->>> t = Top()
->>> t.save()
->>> m = Middle()
->>> m.save()
->>> b = Bottom()
->>> b.save()
->>> Top.objects.all()
-[<Top: Top object>, <Middle: Middle object>, <Bottom: Bottom object>]
->>> Middle.objects.all()
-[<Middle: Middle object>, <Bottom: Bottom object>]
->>> Bottom.objects.all()
-[<Bottom: Bottom object>]
-
 
 >>> settings.DEBUG=False
 
 """}
 
+
+class RegressionTests(TestCase):
+
+    def test_for_query_result_incomplete_with_inheritance(self):
+        """ https://github.com/bconstantin/django_polymorphic/issues/15 """
+
+        top = Top()
+        top.save()
+        middle = Middle()
+        middle.save()
+        bottom = Bottom()
+        bottom.save()
+
+        expected_queryset = [top, middle, bottom]
+        self.assertQuerysetEqual(Top.objects.all(), [repr(r) for r in expected_queryset])
+
+        expected_queryset = [middle, bottom]
+        self.assertQuerysetEqual(Middle.objects.all(), [repr(r) for r in expected_queryset])
+
+        expected_queryset = [bottom]
+        self.assertQuerysetEqual(Bottom.objects.all(), [repr(r) for r in expected_queryset])
+
